==> wire-grpc-client-3.2.0-javadoc.jar: wire-schema/com.squareup.wire.schema/-pruning-rules/-builder/index.md <==
[wire-schema](../../../index.md) / [com.squareup.wire.schema](../../index.md) / [PruningRules](../index.md) / [Builder](./index.md)

# Builder

`class Builder`

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `Builder()` |

### Functions

| Name | Summary |
|---|---|
| [addRoot](add-root.md) | `fun addRoot(identifier: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): <ERROR CLASS>`<br>`fun addRoot(identifiers: `[`Iterable`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`>): <ERROR CLASS>` |
| [build](build.md) | `fun build(): `[`PruningRules`](../index.md) |
| [prune](prune.md) | `fun prune(identifier: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): <ERROR CLASS>`<br>`fun prune(identifiers: `[`Iterable`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`>): <ERROR CLASS>` |
| [since](since.md) | `fun since(since: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): <ERROR CLASS>`<br>The exclusive lower bound of the version range. Fields with `until` values greater than this are retained. |
| [until](until.md) | `fun until(until: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): <ERROR CLASS>`<br>The inclusive upper bound of the version range. Fields with `since` values less than or equal to this are retained. |

==> wire-grpc-client-3.2.2-javadoc.jar: wire-schema/com.squareup.wire.schema/-pruning-rules/-builder/index.md <==
[wire-schema](../../../index.md) / [com.squareup.wire.schema](../../index.md) / [PruningRules](../index.md) / [Builder](./index.md)

# Builder

`class Builder`

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `Builder()` |

### Functions

| Name | Summary |
|---|---|
| [addRoot](add-root.md) | `fun addRoot(identifier: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): <ERROR CLASS>`<br>`fun addRoot(identifiers: `[`Iterable`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`>): <ERROR CLASS>` |
| [build](build.md) | `fun build(): `[`PruningRules`](../index.md) |
| [only](only.md) | `fun only(only: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): <ERROR CLASS>`<br>The only version of the version range. Fields with `until` values greater than this, as well as fields with `since` values less than or equal to this, are retained. |
| [prune](prune.md) | `fun prune(identifier: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): <ERROR CLASS>`<br>`fun prune(identifiers: `[`Iterable`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-iterable/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`>): <ERROR CLASS>` |
| [since](since.md) | `fun since(since: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): <ERROR CLASS>`<br>The exclusive lower bound of the version range. Fields with `until` values greater than this are retained. |
| [until](until.md) | `fun until(until: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`?): <ERROR CLASS>`<br>The inclusive upper bound of the version range. Fields with `since` values less than or equal to this are retained. |
